// define the quiz questions
const quiz = [
  {
    question: "What is the capital of France?",
    options: ["London", "Paris", "Berlin", "Madrid"],
    answer: 2,
    tips: [
      "The Eiffel Tower is located here.",
      "The city is known for its fashion and cuisine.",
      "The city is located in Western Europe.",
    ],
  },
  {
    question: "What is the tallest mammal?",
    options: ["Giraffe", "Elephant", "Hippopotamus", "Rhinoceros"],
    answer: 0,
    tips: [
      "This animal has a long neck.",
      "This animal is found in Africa.",
      "This animal is herbivorous.",
    ],
  },
  {
    question: "What is the largest planet in our solar system?",
    options: ["Venus", "Mars", "Jupiter", "Saturn"],
    answer: 2,
    tips: [
      "This planet has a famous red spot on it.",
      "This planet is known for its many moons.",
      "This planet is the fifth from the sun.",
    ],
  },
  {
    question: "What is the capital of Australia?",
    options: ["Melbourne", "Canberra", "Sydney", "Brisbane"],
    answer: 1,
    tips: [
      "This city is located in the southeastern part of the country.",
      "This city is home to the Parliament House.",
      "This city was chosen as the capital in 1908.",
    ],
  },
];

let currentQuestion = -1;
let score = 0;
let usedTips = [];
let answeredQuestions = [];

// function to display the introduction
function displayIntro() {
  // display the question selection buttons
  const introElement = document.getElementById("intro");
  introElement.innerHTML = "";
  for (let i = 0; i < quiz.length; i++) {
    const questionButton = document.createElement("button");
    questionButton.id = `question${i + 1}`;
    questionButton.innerHTML = `Question ${i + 1}`;
    questionButton.addEventListener("click", () => selectQuestion(i));
    introElement.appendChild(questionButton);
  }
}

// function to select a question
function selectQuestion(questionIndex) {
  // disable the selected question button
  const questionButton = document.getElementById(`question${questionIndex + 1}`);
  questionButton.disabled = true;

  // add the question to the answered questions
  answeredQuestions.push(questionIndex);

  // update the current question index
  currentQuestion = questionIndex;

  // display the selected question
  displayQuestion();
}

// function to display the next question
function displayQuestion() {
  // enable the question buttons
  const questionButtons = document.getElementById("intro").getElementsByTagName("button");
  for (let i = 0; i < questionButtons.length; i++) {
    questionButtons[i].disabled = answeredQuestions.includes(i) || currentQuestion === i;
  }

  // display the question and answer choices
  const questionElement = document.getElementById("question-text");
  questionElement.innerHTML = quiz[currentQuestion].question;

  const optionsElement = document.getElementById("options");
  optionsElement.innerHTML = "";
  for (let i = 0; i < quiz[currentQuestion].options.length; i++) {
    const option = quiz[currentQuestion].options[i];
    const optionElement = document.createElement("button");
    optionElement.innerHTML = option;
    optionElement.addEventListener("click", () => selectAnswer(i));
    optionsElement.appendChild(optionElement);
}

// reset the used tips
usedTips = [];

// display the score and tips
const scoreElement = document.getElementById("score");
scoreElement.innerHTML = Score: ${score};

const tipsElement = document.getElementById("tips");
tipsElement.innerHTML = "";
for (let i = 0; i < quiz[currentQuestion].tips.length; i++) {
const tip = quiz[currentQuestion].tips[i];
const tipElement = document.createElement("button");
tipElement.innerHTML = Tip ${i + 1};
tipElement.addEventListener("click", () => useTip(i));
tipsElement.appendChild(tipElement);
}
}

// function to select an answer
function selectAnswer(answerIndex) {
// disable the answer choice buttons
const optionsElement = document.getElementById("options");
const optionButtons = optionsElement.getElementsByTagName("button");
for (let i = 0; i < optionButtons.length; i++) {
optionButtons[i].disabled = true;
}

// calculate the score
const answer = quiz[currentQuestion].answer;
if (answerIndex === answer) {
// correct answer
if (usedTips.length === 0) {
score += 4;
} else {
score += 3;
}
} else {
// wrong answer
}

// display the score and correct answer
const scoreElement = document.getElementById("score");
scoreElement.innerHTML = Score: ${score};

const answerElement = document.createElement("p");
answerElement.innerHTML = The correct answer is ${quiz[currentQuestion].options[answer]}.;
optionsElement.appendChild(answerElement);

// display the question selection buttons
displayIntro();
}

// function to use a tip
function useTip(tipIndex) {
// disable the tip button
const tipsElement = document.getElementById("tips");
const tipButtons = tipsElement.getElementsByTagName("button");
tipButtons[tipIndex].disabled = true;

// add the tip to the used tips
usedTips.push(tipIndex);

// calculate the score
if (usedTips.length === 1) {
score--;
}

// display the score and tip
const scoreElement = document.getElementById("score");
scoreElement.innerHTML = Score: ${score};

const tip = quiz[currentQuestion].tips[tipIndex];
const tipElement = document.createElement("p");
tipElement.innerHTML = tip;
tipsElement.appendChild(tipElement);
}

// display the introduction
displayIntro();
